==> captcha_captchetat-1.0.0.tar.gz: captcha_captchetat/src/Client/CaptchaClientInterface.php <==
<?php

declare(strict_types=1);

namespace Drupal\captcha_captchetat\Client;

/**
 * Provide Captcha API client interface to request services.
 */
interface CaptchaClientInterface {

  /**
   * The generated captcha input contains identifier.
   *
   * @var string
   */
  const CAPTCHA_INPUT_ID = 'BDC_VCID_captchaFR';

  /**
   * Client base URLs.
   *
   * @var string
   */
  const BASE_URL_SANDBOX = 'https://sandbox-api.piste.gouv.fr/';
  const BASE_URL_PROD = 'https://api.piste.gouv.fr/';

  /**
   * Available captcha modes.
   *
   * @var string
   */
  const MODE_BACKEND = 'backend';
  const MODE_FRONTAL = 'frontal';

  /**
   * List available object types.
   *
   * @var string[]
   */
  const MODES = [
    self::MODE_BACKEND,
    self::MODE_FRONTAL,
  ];

  /**
   * Available object types.
   *
   * @var string
   */
  const OBJECT_TYPE_HTML = 'html';
  const OBJECT_TYPE_IMAGE = 'image';
  const OBJECT_TYPE_LAYOUT_STYLESHEET = 'layout-stylesheet';
  const OBJECT_TYPE_P = 'p';
  const OBJECT_TYPE_RELOAD_DISABLED_ICON = 'reload-disabled-icon';
  const OBJECT_TYPE_RELOAD_ICON = 'reload-icon';
  const OBJECT_TYPE_SCRIPT_INCLUDE = 'script-include';
  const OBJECT_TYPE_SOUND = 'sound';
  const OBJECT_TYPE_SOUND_DISABLED_ICON = 'sound-disabled-icon';
  const OBJECT_TYPE_SOUND_ICON = 'sound-icon';

  /**
   * List available object types.
   *
   * @var string[]
   */
  const OBJECT_TYPES = [
    self::OBJECT_TYPE_HTML,
    self::OBJECT_TYPE_IMAGE,
    self::OBJECT_TYPE_LAYOUT_STYLESHEET,
    self::OBJECT_TYPE_P,
    self::OBJECT_TYPE_RELOAD_DISABLED_ICON,
    self::OBJECT_TYPE_RELOAD_ICON,
    self::OBJECT_TYPE_SCRIPT_INCLUDE,
    self::OBJECT_TYPE_SOUND,
    self::OBJECT_TYPE_SOUND_DISABLED_ICON,
    self::OBJECT_TYPE_SOUND_ICON,
  ];

  /**
   * Available captcha types.
   *
   * @var string
   */
  const TYPE_EN = 'captchaEN';
  const TYPE_FR = 'captchaFR';
  const TYPE_ALPHABETIC_6_7_EN = 'alphabetique6_7CaptchaEN';
  const TYPE_ALPHABETIC_6_7_FR = 'alphabetique6_7CaptchaFR';
  const TYPE_ALPHABETIC_12_EN = 'alphabetique12CaptchaEN';
  const TYPE_ALPHABETIC_12_FR = 'alphabetique12CaptchaFR';
  const TYPE_ALPHANUMERIC_12_EN = 'alphanumerique12CaptchaEN';
  const TYPE_ALPHANUMERIC_12_FR = 'alphanumerique12CaptchaFR';
  const TYPE_NUMERICAL_6_7_EN = 'numerique6_7CaptchaEN';
  const TYPE_NUMERICAL_6_7_FR = 'numerique6_7CaptchaFR';
  const TYPE_NUMERICAL_12_EN = 'numerique12CaptchaEN';
  const TYPE_NUMERICAL_12_FR = 'numerique12CaptchaFR';

  /**
   * List available captcha types.
   *
   * @var string[]
   */
  const TYPES = [
    self::TYPE_EN,
    self::TYPE_FR,
    self::TYPE_ALPHABETIC_6_7_EN,
    self::TYPE_ALPHABETIC_6_7_FR,
    self::TYPE_ALPHABETIC_12_EN,
    self::TYPE_ALPHABETIC_12_FR,
    self::TYPE_ALPHANUMERIC_12_EN,
    self::TYPE_ALPHANUMERIC_12_FR,
    self::TYPE_NUMERICAL_6_7_EN,
    self::TYPE_NUMERICAL_6_7_FR,
    self::TYPE_NUMERICAL_12_EN,
    self::TYPE_NUMERICAL_12_FR,
  ];

  /**
   * Request the captcha service.
   *
   * @param string $mode
   *   The captcha loading mode.
   * @param string $objectType
   *   The object type to get.
   * @param string|null $captchaType
   *   The captcha type to get.
   * @param string|null $captchaId
   *   The captcha identifier (if captcha is already generated).
   *
   * @return string|null
   *   The generated captcha or null if request failed.
   */
  public function captcha(
    string $mode = self::MODE_FRONTAL,
    string $objectType = self::OBJECT_TYPE_HTML,
    ?string $captchaType = NULL,
    ?string $captchaId = NULL
  ): ?string;

  /**
   * Request the captcha info service.
   *
   * @param string $captchaId
   *   The captcha identifier.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function captchaInfo(string $captchaId): ?array;

  /**
   * Request the captcha validation service.
   *
   * @param string $captchaId
   *   The captcha identifier.
   * @param string $code
   *   The code input by the user.
   *
   * @return string|null
   *   The service response or null if request failed.
   */
  public function captchaValidate(
    string $captchaId,
    string $code
  ): ?string;

  /**
   * Request the healthcheck service.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function healthcheck(): ?array;

  /**
   * Request the info service.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function info(): ?array;

  /**
   * Request the version service.
   *
   * @return string|null
   *   The service response or null if request failed.
   */
  public function version(): ?string;

}

==> captcha_captchetat-1.0.1.tar.gz: captcha_captchetat/src/Client/CaptchaClientInterface.php <==
<?php

declare(strict_types=1);

namespace Drupal\captcha_captchetat\Client;

/**
 * Provide Captcha API client interface to request services.
 */
interface CaptchaClientInterface {

  /**
   * The generated captcha input contains identifier.
   * The input identifier is the concatenation of a prefix and the type of captcha generated.
   *
   * @var string
   */
  const CAPTCHA_INPUT_ID_PREFIX = 'BDC_VCID_';

  /**
   * Client base URLs.
   *
   * @var string
   */
  const BASE_URL_SANDBOX = 'https://sandbox-api.piste.gouv.fr/';
  const BASE_URL_PROD = 'https://api.piste.gouv.fr/';

  /**
   * Available captcha modes.
   *
   * @var string
   */
  const MODE_BACKEND = 'backend';
  const MODE_FRONTAL = 'frontal';

  /**
   * List available object types.
   *
   * @var string[]
   */
  const MODES = [
    self::MODE_BACKEND,
    self::MODE_FRONTAL,
  ];

  /**
   * Available object types.
   *
   * @var string
   */
  const OBJECT_TYPE_HTML = 'html';
  const OBJECT_TYPE_IMAGE = 'image';
  const OBJECT_TYPE_LAYOUT_STYLESHEET = 'layout-stylesheet';
  const OBJECT_TYPE_P = 'p';
  const OBJECT_TYPE_RELOAD_DISABLED_ICON = 'reload-disabled-icon';
  const OBJECT_TYPE_RELOAD_ICON = 'reload-icon';
  const OBJECT_TYPE_SCRIPT_INCLUDE = 'script-include';
  const OBJECT_TYPE_SOUND = 'sound';
  const OBJECT_TYPE_SOUND_DISABLED_ICON = 'sound-disabled-icon';
  const OBJECT_TYPE_SOUND_ICON = 'sound-icon';

  /**
   * List available object types.
   *
   * @var string[]
   */
  const OBJECT_TYPES = [
    self::OBJECT_TYPE_HTML,
    self::OBJECT_TYPE_IMAGE,
    self::OBJECT_TYPE_LAYOUT_STYLESHEET,
    self::OBJECT_TYPE_P,
    self::OBJECT_TYPE_RELOAD_DISABLED_ICON,
    self::OBJECT_TYPE_RELOAD_ICON,
    self::OBJECT_TYPE_SCRIPT_INCLUDE,
    self::OBJECT_TYPE_SOUND,
    self::OBJECT_TYPE_SOUND_DISABLED_ICON,
    self::OBJECT_TYPE_SOUND_ICON,
  ];

  /**
   * Available captcha types.
   *
   * @var string
   */
  const TYPE_EN = 'captchaEN';
  const TYPE_FR = 'captchaFR';
  const TYPE_ALPHABETIC_6_7_EN = 'alphabetique6_7CaptchaEN';
  const TYPE_ALPHABETIC_6_7_FR = 'alphabetique6_7CaptchaFR';
  const TYPE_ALPHABETIC_12_EN = 'alphabetique12CaptchaEN';
  const TYPE_ALPHABETIC_12_FR = 'alphabetique12CaptchaFR';
  const TYPE_ALPHANUMERIC_12_EN = 'alphanumerique12CaptchaEN';
  const TYPE_ALPHANUMERIC_12_FR = 'alphanumerique12CaptchaFR';
  const TYPE_NUMERICAL_6_7_EN = 'numerique6_7CaptchaEN';
  const TYPE_NUMERICAL_6_7_FR = 'numerique6_7CaptchaFR';
  const TYPE_NUMERICAL_12_EN = 'numerique12CaptchaEN';
  const TYPE_NUMERICAL_12_FR = 'numerique12CaptchaFR';

  /**
   * List available captcha types.
   *
   * @var string[]
   */
  const TYPES = [
    self::TYPE_EN,
    self::TYPE_FR,
    self::TYPE_ALPHABETIC_6_7_EN,
    self::TYPE_ALPHABETIC_6_7_FR,
    self::TYPE_ALPHABETIC_12_EN,
    self::TYPE_ALPHABETIC_12_FR,
    self::TYPE_ALPHANUMERIC_12_EN,
    self::TYPE_ALPHANUMERIC_12_FR,
    self::TYPE_NUMERICAL_6_7_EN,
    self::TYPE_NUMERICAL_6_7_FR,
    self::TYPE_NUMERICAL_12_EN,
    self::TYPE_NUMERICAL_12_FR,
  ];

  /**
   * Request the captcha service.
   *
   * @param string $mode
   *   The captcha loading mode.
   * @param string $objectType
   *   The object type to get.
   * @param string|null $captchaType
   *   The captcha type to get.
   * @param string|null $captchaId
   *   The captcha identifier (if captcha is already generated).
   *
   * @return string|null
   *   The generated captcha or null if request failed.
   */
  public function captcha(
    string $mode = self::MODE_FRONTAL,
    string $objectType = self::OBJECT_TYPE_HTML,
    ?string $captchaType = NULL,
    ?string $captchaId = NULL
  ): ?string;

  /**
   * Request the captcha info service.
   *
   * @param string $captchaId
   *   The captcha identifier.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function captchaInfo(string $captchaId): ?array;

  /**
   * Request the captcha validation service.
   *
   * @param string $captchaId
   *   The captcha identifier.
   * @param string $code
   *   The code input by the user.
   *
   * @return string|null
   *   The service response or null if request failed.
   */
  public function captchaValidate(
    string $captchaId,
    string $code
  ): ?string;

  /**
   * Request the healthcheck service.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function healthcheck(): ?array;

  /**
   * Request the info service.
   *
   * @return array|null
   *   The service response or null if request failed.
   */
  public function info(): ?array;

  /**
   * Request the version service.
   *
   * @return string|null
   *   The service response or null if request failed.
   */
  public function version(): ?string;

}
